@@ -26,13 +26,10 @@ definitions it links to.  If not, report the bug!
 import os.path
 import string
 
-from hypothesis._settings import note_deprecation
+from hypothesis import strategies as st
 from hypothesis.errors import InvalidArgument
 from hypothesis.internal.conjecture import utils as cu
-from hypothesis.internal.reflection import deprecated_posargs
-from hypothesis.strategies._internal import core as st
-from hypothesis.strategies._internal.ipaddress import ip_addresses
-from hypothesis.strategies._internal.strategies import SearchStrategy
+from hypothesis.strategies._internal.utils import defines_strategy
 
 URL_SAFE_CHARACTERS = frozenset(string.ascii_letters + string.digits + "$-_.+!*'(),~")
 
@@ -53,7 +50,7 @@ assert _tlds[0].startswith("#")
 TOP_LEVEL_DOMAINS = ["COM"] + sorted(_tlds[1:], key=len)
 
 
-class DomainNameStrategy(SearchStrategy):
+class DomainNameStrategy(st.SearchStrategy):
     @staticmethod
     def clean_inputs(minimum, maximum, value, variable_name):
         if value is None:
@@ -134,19 +131,18 @@ class DomainNameStrategy(SearchStrategy):
         return domain
 
 
-@st.defines_strategy(force_reusable_values=True)
-@deprecated_posargs
+@defines_strategy(force_reusable_values=True)
 def domains(
     *, max_length: int = 255, max_element_length: int = 63
-) -> SearchStrategy[str]:
+) -> st.SearchStrategy[str]:
     """Generate :rfc:`1035` compliant fully qualified domain names."""
     return DomainNameStrategy(
         max_length=max_length, max_element_length=max_element_length
     )
 
 
-@st.defines_strategy(force_reusable_values=True)
-def urls() -> SearchStrategy[str]:
+@defines_strategy(force_reusable_values=True)
+def urls() -> st.SearchStrategy[str]:
     """A strategy for :rfc:`3986`, generating http/https URLs."""
 
     def url_encode(s):
@@ -159,25 +155,3 @@ def urls() -> SearchStrategy[str]:
     return st.builds(
         "{}://{}{}/{}".format, schemes, domains(), st.just("") | ports, paths
     )
-
-
-@st.defines_strategy(force_reusable_values=True)
-def ip4_addr_strings() -> SearchStrategy[str]:
-    note_deprecation(
-        "Use `ip_addresses(v=4).map(str)` instead of `ip4_addr_strings()`; "
-        "the provisional strategy is less flexible and will be removed.",
-        since="2020-01-21",
-        has_codemod=False,
-    )
-    return ip_addresses(v=4).map(str)
-
-
-@st.defines_strategy(force_reusable_values=True)
-def ip6_addr_strings() -> SearchStrategy[str]:
-    note_deprecation(
-        "Use `ip_addresses(v=6).map(str)` instead of `ip6_addr_strings()`; "
-        "the provisional strategy is less flexible and will be removed.",
-        since="2020-01-21",
-        has_codemod=False,
-    )
-    return ip_addresses(v=6).map(str)
